@@ -32,7 +32,10 @@ WantedBy=multi-user.target\
 
 def create_nginx_file(project_path,prj_name,domain_name):
     def wrapper():
-        os.mkdir("/etc/nginx/sites-available")
+        try:
+            os.mkdir("/etc/nginx/sites-available")
+        except Exception as e:
+            pass
         with open(f"/etc/nginx/sites-available/{prj_name}.conf","w") as f:
             f.write(f"""\
 server {{
